@@ -1,6 +1,6 @@
 #  fixtures: Fixtures with cleanups for testing and convenience.
 #
-# Copyright (c) 2010, Robert Collins <robertc@robertcollins.net>
+# Copyright (c) 2010, 2011, Robert Collins <robertc@robertcollins.net>
 # 
 # Licensed under either the Apache License, Version 2.0 or the BSD 3-clause
 # license at the users choice. A copy of both licenses are available in the
@@ -36,40 +36,55 @@ Most users will want to look at TestWithFixtures and Fixture, to start with.
 # established at this point, and setup.py will use a version of next-$(revno).
 # If the releaselevel is 'final', then the tarball will be major.minor.micro.
 # Otherwise it is major.minor.micro~$(revno).
-__version__ = (0, 3, 7, 'final', 0)
+__version__ = (0, 3, 8, 'final', 0)
 
 __all__ = [
+    'EnvironmentVariable',
     'EnvironmentVariableFixture',
+    'FakeLogger',
+    'FakePopen',
     'Fixture',
     'FunctionFixture',
     'LoggerFixture',
     'MethodFixture',
     'MonkeyPatch',
+    'NestedTempfile',
     'PackagePathEntry',
     'PopenFixture',
     'PythonPackage',
     'PythonPathEntry',
     'TempDir',
     'TestWithFixtures',
+    'Timeout',
+    'TimeoutException',
     ]
 
 
-from fixtures.fixture import Fixture, FunctionFixture, MethodFixture
+from fixtures.fixture import (
+    Fixture,
+    FunctionFixture,
+    MethodFixture,
+    )
 from fixtures._fixtures import (
+    EnvironmentVariable,
     EnvironmentVariableFixture,
+    FakeLogger,
+    FakePopen,
     LoggerFixture,
     MonkeyPatch,
+    NestedTempfile,
     PackagePathEntry,
     PopenFixture,
     PythonPackage,
     PythonPathEntry,
     TempDir,
+    Timeout,
+    TimeoutException,
     )
 from fixtures.testcase import TestWithFixtures
 
 
 def test_suite():
-    import unittest
     import fixtures.tests
     return fixtures.tests.test_suite()
 
